@@ -75,11 +75,6 @@ struct _GeditViewClass
 
 	/* FIXME: Do we need placeholders ? */
 
-	/* Key bindings */
-	gboolean (* start_interactive_search)	(GeditView       *view);
-	gboolean (* start_interactive_goto_line)(GeditView       *view);
-	gboolean (* reset_searched_text)	(GeditView       *view);
-
 	void	 (* drop_uris)			(GeditView	 *view,
 						 gchar          **uri_list);
 };
@@ -106,4 +101,5 @@ void 		 gedit_view_set_font		(GeditView       *view,
 G_END_DECLS
 
 #endif /* __GEDIT_VIEW_H__ */
-/* ex:ts=8:noet: */
+
+/* ex:set ts=8 noet: */
